# Prototype

This portion of the repo houses work that is not yet ready for consumption by users. Examples:
- Algorithms that are in-development and haven't been fully tested and/or documented yet
- Exploratory work that might never be useful to users
- Personal experiments or demonstrations that may be of interest to other DAML contributors

The work in this directory will have significantly relaxed requirements for merging in to `main`. Due to the nature of Python it's likely that users could still access code placed here, it should at least be well sign-posted as prototype code that isn't yet ready for primetime. In concept the more research-oriented DAML contributors will evolve and develop a set of review criteria that make sense, and to that end this directory will require the approval of a DAML researcher in order to merge in to `main`.
